<?php
function pw_generate_whatsapp_link() {
    // Obtener valores configurables
    $phone_number = get_option('pw_whatsapp_number', '543425164100'); // Número de WhatsApp configurable
    $message_start = get_option('pw_message_start', 'Hola, quiero hacer la siguiente compra:');
    $message_end = get_option('pw_message_end', 'Gracias.');

    if (!WC()->cart) {
        wp_send_json_error(['message' => 'El carrito está vacío.']);
        return;
    }

    $items = WC()->cart->get_cart();
    if (empty($items)) {
        wp_send_json_error(['message' => 'El carrito está vacío.']);
        return;
    }

    // Iniciar el mensaje con el texto configurado
    $message = $message_start . "\n\n";

    foreach ($items as $item) {
        $product = $item['data'];
        $quantity = $item['quantity'];
        $price = wc_get_price_to_display($product);
        $price = number_format($price, 0, ',', '.'); // Formato con separador de miles
        $url = get_permalink($product->get_id());

        $message .= "{$quantity}x - *" . $product->get_name() . "*\n";
        $message .= "*Precio:* $ {$price}\n";
        $message .= "*URL:* {$url}\n\n";
    }

    // Obtener el total correctamente y formatearlo
    $total = WC()->cart->get_total('');
    $total = strip_tags(html_entity_decode($total));
    $total = floatval(str_replace('.', '', $total)); // Convertir a número sin puntos de miles
    $total = number_format($total, 0, ',', '.'); // Aplicar formato con separadores de miles

    // Calcular la cuota (total dividido por 3)
    $cuota = $total / 3;
    $cuota = number_format($cuota, 0, ',', '.'); // Formatear la cuota con separador de miles

    // Calcular el total con 20% de descuento
    $descuento = $total * 0.8;
    $descuento = number_format($descuento, 0, ',', '.'); // Formatear el total con descuento

    $message .= "*Total:* $ {$total}\n\n";
    $message .= $message_end; // Agregar el mensaje final

    // Generar la URL de WhatsApp
    $whatsapp_url = "https://web.whatsapp.com/send?phone={$phone_number}&text=" . urlencode($message);

    wp_send_json_success(['url' => $whatsapp_url]);
}

// Función para calcular la cuota del total y usarlo como shortcode
function pw_calcular_cuota_total() {
    if (!WC()->cart) {
        return '0';
    }

    $total = WC()->cart->get_total('');
    $total = strip_tags(html_entity_decode($total)); // Limpiar HTML
    $total = floatval(str_replace('.', '', $total)); // Convertir a número eliminando puntos de miles

    if ($total == 0) {
        return '0';
    }

    $cuota = $total / 3;
    return number_format($cuota, 0, ',', '.'); // Formatear la cuota con separador de miles
}

// Función para calcular el total con 20% de descuento y usarlo como shortcode
function pw_calcular_descuento_total() {
    if (!WC()->cart) {
        return '0';
    }

    $total = WC()->cart->get_total('');
    $total = strip_tags(html_entity_decode($total)); // Limpiar HTML
    $total = floatval(str_replace('.', '', $total)); // Convertir a número eliminando puntos de miles

    if ($total == 0) {
        return '0';
    }

    $descuento = $total * 0.8; // Aplicar 20% de descuento
    return number_format($descuento, 0, ',', '.'); // Formatear con separador de miles
}

// Registrar los shortcodes
add_shortcode('cuotadeltotal', 'pw_calcular_cuota_total');
add_shortcode('descuentodeltotal', 'pw_calcular_descuento_total');
